@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
 
-"""
-Tests for datetime generator
-"""
+"""Tests for datetime generator."""
 
-from fauxfactory import FauxFactory
+from fauxfactory import gen_date, gen_datetime
 from fauxfactory.constants import MAX_YEARS, MIN_YEARS
 
 import datetime
@@ -16,27 +14,19 @@ class TestDates(unittest.TestCase):
     Test datetime generator
     """
 
-    @classmethod
-    def setUpClass(cls):
-        """
-        Instantiate our factory object
-        """
-
-        cls.factory = FauxFactory()
-
-    def test_generate_datetime_1(self):
+    def test_gen_datetime_1(self):
         """
         @Test: Create a datetime with no arguments
         @Feature: DateTime Generator
         @Assert: Datetime is created with random values
         """
 
-        result = self.factory.generate_datetime()
+        result = gen_datetime()
         self.assertTrue(
             isinstance(result, datetime.datetime),
             "Data is not instance of datetime.date.")
 
-    def test_generate_datetime_2(self):
+    def test_gen_datetime_2(self):
         """
         @Test: Create a datetime with only min_date
         @Feature: DateTime Generator
@@ -49,10 +39,10 @@ class TestDates(unittest.TestCase):
         min_date = today - datetime.timedelta(seconds=5*60)
 
         for turn in range(10):
-            result = self.factory.generate_datetime(min_date=min_date)
+            result = gen_datetime(min_date=min_date)
             self.assertTrue(result >= min_date)
 
-    def test_generate_datetime_3(self):
+    def test_gen_datetime_3(self):
         """
         @Test: Create a datetime with only max_date
         @Feature: DateTime Generator
@@ -65,10 +55,10 @@ class TestDates(unittest.TestCase):
         max_date = today + datetime.timedelta(seconds=5*60)
 
         for turn in range(10):
-            result = self.factory.generate_datetime(max_date=max_date)
+            result = gen_datetime(max_date=max_date)
             self.assertTrue(result <= max_date)
 
-    def test_generate_datetime_4(self):
+    def test_gen_datetime_4(self):
         """
         @Test: Create a datetime with a 5-days datetime range
         @Feature: DateTime Generator
@@ -83,14 +73,14 @@ class TestDates(unittest.TestCase):
         max_date = today + datetime.timedelta(seconds=5*60)
 
         for turn in range(10):
-            result = self.factory.generate_datetime(
+            result = gen_datetime(
                 min_date=min_date,
                 max_date=max_date
             )
             self.assertTrue(result >= min_date)
             self.assertTrue(result <= max_date)
 
-    def test_generate_datetime_5(self):
+    def test_gen_datetime_5(self):
         """
         @Test: Create a datetime with min_date = None
         @Feature: DateTime Generator
@@ -104,14 +94,14 @@ class TestDates(unittest.TestCase):
         max_date = min_date + datetime.timedelta(365 * 1)
 
         for turn in range(20):
-            result = self.factory.generate_datetime(
+            result = gen_datetime(
                 min_date=None,
                 max_date=max_date
             )
             self.assertTrue(result.year <= max_date.year)
             self.assertTrue(result.year >= min_date.year)
 
-    def test_generate_datetime_6(self):
+    def test_gen_datetime_6(self):
         """
         @Test: Create a datetime with max_date == None
         @Feature: DateTime Generator
@@ -125,14 +115,14 @@ class TestDates(unittest.TestCase):
         min_date = max_date - datetime.timedelta(365 * 1)
 
         for turn in range(20):
-            result = self.factory.generate_datetime(
+            result = gen_datetime(
                 min_date=min_date,
                 max_date=None
             )
             self.assertTrue(result.year <= max_date.year, result)
             self.assertTrue(result.year >= min_date.year, result)
 
-    def test_generate_datetime_7(self):
+    def test_gen_datetime_7(self):
         """
         @Test: Create a datetime with specified datetime ranges
         @Feature: DateTime Generator
@@ -147,14 +137,14 @@ class TestDates(unittest.TestCase):
                     datetime.timedelta(365 * MAX_YEARS))
 
         for turn in range(20):
-            result = self.factory.generate_datetime(
+            result = gen_datetime(
                 min_date=min_date,
                 max_date=max_date
             )
             self.assertTrue(result.year <= max_date.year, result)
             self.assertTrue(result.year >= min_date.year, result)
 
-    def test_generate_datetime_8(self):
+    def test_gen_datetime_8(self):
         """
         @Test: Create a datetime with non-Date arguments
         @Feature: DateTime Generator
@@ -162,12 +152,12 @@ class TestDates(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_datetime(
+            gen_datetime(
                 min_date='',
                 max_date=''
             )
 
-    def test_generate_datetime_9(self):
+    def test_gen_datetime_9(self):
         """
         @Test: Create a datetime with non-Date arguments
         @Feature: DateTime Generator
@@ -175,12 +165,12 @@ class TestDates(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_datetime(
+            gen_datetime(
                 min_date='abc',
                 max_date='def'
             )
 
-    def test_generate_datetime_10(self):
+    def test_gen_datetime_10(self):
         """
         @Test: Create a datetime with non-Date arguments
         @Feature: DateTime Generator
@@ -188,12 +178,12 @@ class TestDates(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_datetime(
+            gen_datetime(
                 min_date=1,
                 max_date=1
             )
 
-    def test_generate_datetime_11(self):
+    def test_gen_datetime_11(self):
         """
         @Test: Create a datetime with non-Date arguments
         @Feature: DateTime Generator
@@ -201,12 +191,12 @@ class TestDates(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_datetime(
+            gen_datetime(
                 min_date=(1,),
                 max_date=(2, 3, 4)
             )
 
-    def test_generate_datetime_12(self):
+    def test_gen_datetime_12(self):
         """
         @Test: Create a datetime with non-Date arguments
         @Feature: DateTime Generator
@@ -214,12 +204,12 @@ class TestDates(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_datetime(
+            gen_datetime(
                 min_date=['a', 'b'],
                 max_date=['c', 'd', 'e']
             )
 
-    def test_generate_datetime_13(self):
+    def test_gen_datetime_13(self):
         """
         @Test: Create a datetime with min_date > max_date
         @Feature: DateTime Generator
@@ -232,12 +222,12 @@ class TestDates(unittest.TestCase):
         min_date = today + datetime.timedelta(seconds=5*60)
 
         with self.assertRaises(AssertionError):
-            self.factory.generate_datetime(
+            gen_datetime(
                 min_date=min_date,
                 max_date=today
             )
 
-    def test_generate_date_14(self):
+    def test_gen_date_14(self):
         """
         @Test: max-date must be a Datetime type
         @Feature: DateTime Generator
@@ -245,7 +235,7 @@ class TestDates(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_date(
+            gen_date(
                 min_date=datetime.datetime.now(),
                 max_date='foo'
             )
